@@ -1,8 +1,8 @@
 import numpy as np
 import pandas as pd
-from typing import Union, Sequence, Callable, Iterable, Tuple
+from typing import Union, Sequence, Callable, Iterable, Tuple, Any
 
-__all__ = ["Sequence", "Callable", "Iterable", "nDFloat", "nDInt", "Coords", "Slices", "Dims"]
+__all__ = ["Sequence", "Callable", "Iterable", "nDFloat", "nDInt", "Coords", "Slices", "Dims", "Any"]
 
 nDFloat = Union[Sequence[float], float]
 nDInt = Union[Sequence[int], int]
